package theo
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Theo.ComparableSource
Input signature for primitive theories.
Modules satisfying this interface can be lifted into BDD theories (like Leq or Eq). Users must provide standard comparison and hashing operations for their atomic types.
The type of values in the theory (e.g., string, int, Version.t).
Total ordering. Returns negative if first < second, 0 if equal, positive if first > second.